@@ -111,10 +111,17 @@ class CRUDViews(UserPassesTestMixin, SingleTableView):
             def test_func(self):
                 has_perm = super().test_func()
                 if has_perm:
-                    record = list_view_instance.get_queryset().filter(id=self.kwargs['pk']).first()
-                    return record and list_view_instance.allow_edit_for_record(record)
+                    return list_view_instance.get_queryset().filter(id=self.kwargs['pk']).exists()
                 return has_perm
 
+            def get_context_data(self, **kwargs):
+                context_data = super().get_context_data(**kwargs) or {}
+                record = list_view_instance.get_queryset().filter(id=self.kwargs['pk']).first()
+                context_data.update(
+                    disable_submit=not list_view_instance.allow_edit_for_record(record)
+                )
+                return context_data
+
         class CRUDDeleteView(ViewCommon, DeleteView):
             template_name = 'django_reusable/crud/delete.pug'
 
